/************************************************************
 *
 * 1999 - 2004 (c) Intersect Alliance Pty Ltd.
 *
 * These routines support the reading of the event log file,
 * management of the log file, and drawing the pixmaps
 *
 *
 * SNARE GUI Version 2.4
 *
 ************************************************************/


#include "read_config.h"

#define READ_LOG_INTERVAL       1000	//DEFINES THE READ LOG INTERVAL AS 1000 MILLISECS

#define OPEN_EVENT_FILE			0
#define READ_EVENT_FILE_FROM_START 	1
#define READ_EVENT_FILE_FROM_END	2
#define CLOSE_EVENT_FILE		3

gint update_main_clist(GtkWidget *);
void create_pixmaps(GtkWidget *);
int find_pixmap_type(GdkPixmap *);
int read_log_file_and_type(int);
void draw_alert_level_pixmaps(GtkWidget *);
int check_filename(void);
int open_close_event_file(int);
int declare_new_file(char *);
void set_network_logging_variable(int);

struct read_events_struct {
	GtkWidget *main_window;
	FILE *events_file;
	int read_type;
};
